/*
 * Copyright (C) 2001  Daemon Consulting Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

void speedy_script_find(slotnum_t *gslotnum_p, slotnum_t *sslotnum_p);
int speedy_script_changed();
void speedy_script_close();
int speedy_script_open();
const struct stat *speedy_script_getstat();
int speedy_script_open_failure();
void speedy_script_munmap();
SpeedyMapInfo *speedy_script_mmap(int max_size);
void speedy_script_missing();
